@@ -1,16 +1,14 @@
 import logging
-import logging
 import time
 from asyncio import get_event_loop
 from typing import Optional
 
-from ..event_util import forward_event
 from ..poll import PollData
 from .. import util, create_irc
 from ..channel import Channel, channels
 from ..command import Command, commands, CustomCommandAction, is_command_on_cooldown, get_time_since_execute, \
     update_command_last_execute
-from ..config import cfg, get_nick
+from ..config import cfg, get_nick, get_command_prefix
 from ..config import generate_config
 from ..database import get_custom_command
 from ..disabled_commands import is_command_disabled
@@ -29,6 +27,7 @@ from ..shared import set_bot
 from ..util import stop_all_tasks
 from ..command_whitelist import is_command_whitelisted, send_message_on_command_whitelist_deny
 from ..poll import poll_event_processor_loop
+from ..event_util import forward_event_with_results, forward_event
 
 
 # noinspection PyMethodMayBeStatic
@@ -81,7 +80,6 @@ class BaseBot:
     async def on_privmsg_received(self, msg: Message) -> None:
         """triggered when a privmsg is received, is not triggered if the msg is a command"""
 
-
     async def on_whisper_sent(self, msg: str, receiver: str, sender: str):
         """
         triggered when the bot sends a whisper to someone
@@ -241,11 +239,7 @@ class BaseBot:
         return None
 
     async def _run_command(self, msg: Message, cmd: Command):
-        if (
-                not await self.on_permission_check(msg, cmd)
-                or not all(await trigger_mod_event(Event.on_permission_check, msg, cmd, channel=msg.channel_name))
-                or not all(await trigger_event(Event.on_permission_check, msg, cmd))
-        ):
+        if (not all(await forward_event_with_results(Event.on_permission_check, msg, cmd, channel=msg.channel_name))):
             return await msg.reply(
                 whisper=True,
                 msg=f'you do not have permission to execute {cmd.fullname} in #{msg.channel_name}, permission required: {cmd.permission}')
@@ -265,10 +259,8 @@ class BaseBot:
             return await msg.reply(
                 f'{cmd.fullname} is on cooldown, seconds left: {cmd.cooldown - get_time_since_execute(msg.channel_name, cmd.fullname)}')
 
-        if (not await self.on_before_command_execute(msg, cmd)
-                or not all(await trigger_mod_event(Event.on_before_command_execute, msg, cmd, channel=msg.channel_name))
-                or not all(await trigger_event(Event.on_before_command_execute, msg, cmd))
-        ):
+        # check that all event listeners return True for this command executing
+        if not all(await forward_event_with_results(Event.on_before_command_execute, msg, cmd, channel=msg.channel_name)):
             return
 
         try:
@@ -278,13 +270,11 @@ class BaseBot:
         except InvalidArgumentsError as e:
             await self._send_cmd_help(msg, cmd, e)
         else:
-            await self.on_after_command_execute(msg, cmd)
-            await trigger_mod_event(Event.on_after_command_execute, msg, cmd, channel=msg.channel_name)
-            await trigger_event(Event.on_after_command_execute, msg, cmd)
+            forward_event(Event.on_after_command_execute, msg, cmd, channel=msg.channel_name)
 
     async def _send_cmd_help(self, msg: Message, cmd: Command, exc: InvalidArgumentsError):
         await msg.reply(
-            f'{exc.reason} - "{cmd.fullname} {cmd.syntax}" - do "{cfg.prefix}help {cmd.fullname}" for more details')
+            f'{exc.reason} - "{cmd.fullname} {cmd.syntax}" - do "{get_command_prefix()}help {cmd.fullname}" for more details')
 
     # kept if needed later
     # def _load_overrides(self):
